@@ -19,6 +19,7 @@ class CredentialType(Enum):
 class CountryCode(Enum):
     INDIA = "IN"
     THAILAND = "TH"
+    PHILIPPINES = "PH"
 
     def __str__(self):
         return self.value
@@ -119,7 +120,7 @@ class UserProfile:
         if self.zone_id:
             rv["zone_id"] = self.zone_id
         if self.dob:
-            rv["dob"] = self.dob
+            rv["dob"] = self.dob.isoformat()
         if self.email:
             rv["email"] = self.email
         if self.img_url:
