@@ -1,6 +1,5 @@
 import json
 from typing import Dict
-from uuid import uuid4, UUID
 from http import HTTPStatus
 
 import pytest
@@ -9,6 +8,8 @@ from user_sdk.domain import User, UserProfile, Session
 from user_sdk.error import TooManyRequests
 from user_sdk.user_service import UserService
 
+from shuttlis.utils import uuid4_str
+
 user_service = UserService(
     authentication_url="http://dummy_authentication",
     profile_url="http://dummy_profile",
@@ -124,7 +125,7 @@ def test_remove_user_specific_feature_from_user_profile():
 @responses.activate
 def test_update_profile_on_adding_user_types_and_user_specific_features():
     user_profile = UserProfile.from_dict(incomplete_user_profile_dict)
-    user_id = UUID(incomplete_user_profile_dict["id"])
+    user_id = incomplete_user_profile_dict["id"]
 
     def request_callback(request):
         payload = json.loads(request.body)
@@ -164,7 +165,7 @@ def test_update_profile_on_adding_user_types_and_user_specific_features():
 
 @responses.activate
 def test_update_profile_returns_429():
-    user_id = UUID(incomplete_user_profile_dict["id"])
+    user_id = incomplete_user_profile_dict["id"]
 
     responses.add(
         responses.PATCH,
@@ -182,7 +183,7 @@ def test_update_profile_returns_429():
 @responses.activate
 def test_update_profile_on_removing_user_types_and_user_specific_features():
     user_profile = UserProfile.from_dict(user_profile_dict)
-    user_id = UUID(incomplete_user_profile_dict["id"])
+    user_id = incomplete_user_profile_dict["id"]
 
     def request_callback(request):
         payload = json.loads(request.body)
@@ -222,7 +223,7 @@ def test_update_profile_on_removing_user_types_and_user_specific_features():
 
 @responses.activate
 def test_get_user_from_session_throws_rte_if_non_ok_response():
-    session_id = str(uuid4())
+    session_id = uuid4_str()
     responses.add(
         responses.GET,
         f"http://dummy_authentication/api/v1/sessions/{session_id}",
@@ -239,7 +240,7 @@ def test_get_user_from_session_throws_rte_if_non_ok_response():
 
 @responses.activate
 def test_get_user_from_active_session_for_ok_response():
-    session_id = str(uuid4())
+    session_id = uuid4_str()
 
     def request_callback(request):
         return HTTPStatus.OK, {}, json.dumps({"data": session_response})
@@ -256,7 +257,7 @@ def test_get_user_from_active_session_for_ok_response():
 
 @responses.activate
 def test_get_user_from_active_session_throws_rte_if_non_ok_response():
-    session_id = str(uuid4())
+    session_id = uuid4_str()
     responses.add(
         responses.GET,
         f"http://dummy_authentication/api/v1/sessions/{session_id}/active",
@@ -273,7 +274,7 @@ def test_get_user_from_active_session_throws_rte_if_non_ok_response():
 
 @responses.activate
 def test_get_user_profiles_count_by_device_id():
-    device_id, count = str(uuid4()), 10
+    device_id, count = uuid4_str(), 10
     responses.add(
         responses.GET,
         f"http://dummy_profile/api/v1/profile_count/by_device_id",
@@ -286,7 +287,7 @@ def test_get_user_profiles_count_by_device_id():
 
 @responses.activate
 def test_get_user_profiles_count_by_device_id_if_non_ok_response():
-    device_id = str(uuid4())
+    device_id = uuid4_str()
     responses.add(
         responses.GET,
         f"http://dummy_profile/api/v1/profile_count/by_device_id",
@@ -300,7 +301,7 @@ def test_get_user_profiles_count_by_device_id_if_non_ok_response():
 
 @responses.activate
 def test_get_devices():
-    user_id, device_id = str(uuid4()), str(uuid4())
+    user_id, device_id = uuid4_str(), uuid4_str()
     responses.add(
         responses.GET,
         f"http://dummy_profile/api/v1/devices/by_user_id",
@@ -314,7 +315,7 @@ def test_get_devices():
 
 @responses.activate
 def test_get_devices_if_non_ok_response():
-    user_id = str(uuid4())
+    user_id = uuid4_str()
     responses.add(
         responses.GET,
         f"http://dummy_profile/api/v1/devices/by_user_id",
