@@ -1,8 +1,8 @@
-from http import HTTPStatus
-from typing import List, Optional, Dict
-
 import requests
+from http import HTTPStatus
+from typing import List, Optional
 
+from user_sdk.domain import CountryCode
 from user_sdk.domain import (
     Session,
     CredentialType,
@@ -29,7 +29,6 @@ from user_sdk.error import (
     TooManyRequests,
 )
 from user_sdk.log import log
-from user_sdk.domain import CountryCode
 
 
 class UserService:
@@ -73,11 +72,12 @@ class UserService:
         body = {
             "identity": identity,
             "credential_type": str(cred_type),
-            "region": str(region),
         }
+
         if cred_type == CredentialType.USERNAME:
             body["password"] = password
         elif cred_type == CredentialType.MOBILE:
+            body["region"] = str(region)
             body["otp"] = otp
             if expiry_seconds:
                 body["expiry_seconds"] = expiry_seconds
